from lxml import etree


class HywelDdaPipeline(object):

    def process_item(self, item, spider):
        """
        The date for HywelDda Spider can be found in <h1> tag of the referer's page
        The committee type can be found in breadcrumb <div> as 4th element as the pattern is as follows:
        'Home > Your Health Board > Statutory Committees of the Board > Audit and Risk Assurance Committee (ARAC) >
        ARAC Meetings 2020'
        If it is a board meeting, the type will be in the 3rd element
        If it is a strategy and planning committee or Integrated Governance Committee,
        the type will be in the 2nd element and with added meeting date
        'Home > Strategy and Planning Committee Meeting 26 January 2015'
        """

        if spider.name == 'HywelDda':
            tree = etree.fromstring(item['referer_html'], etree.HTMLParser())
            date = tree.xpath('.//h1//text()')[0]
            item['helper_date'] = date
            item['helper_committee_type'] = tree.xpath('.//div[@id="breadcrumb"]//text()')[1:4]

        return item
