from scrapy.http import Request
from scrapy.linkextractors import LinkExtractor
from scrapy.spiders import CrawlSpider, Rule

from databot.item import Item


class PowysSpider(CrawlSpider):
    name = 'Powys'
    allowed_domains = ['powysthb.wales.nhs.uk']
    start_urls = ['http://www.powysthb.wales.nhs.uk/board-meetings',
                  'http://www.powysthb.wales.nhs.uk/sub-committees']

    rules = (
        Rule(LinkExtractor(restrict_xpaths=(['//div[@id="pagecontent"]']), deny=('opendoc/')),
                           callback='parse_html', follow=True),
    )

    def parse_html(self, response):
        for url in response.xpath('//a[contains(@href,"opendoc/")]/@href').getall():
            yield Request(
                url=response.urljoin(url),
                callback=self.parse_item,
                cb_kwargs=dict(referer_html=response.text)
            )

    def parse_item(self, response, referer_html):
        item = Item()
        item['name'] = self.name
        item['url'] = response.url
        item['referer_url'] = response.request.headers.get('Referer').decode()
        item['response'] = response.body
        item['referer_html'] = referer_html
        item['content_type'] = response.headers['Content-Type'].decode()
        item['last_modified'] = response.headers['Last-Modified'].decode()
        yield item
