import lxml.html
from scrapy.http import Request
from scrapy.linkextractors import LinkExtractor
from scrapy.spiders import CrawlSpider, Rule

from databot.item import Item


class SwanseaBaySpider(CrawlSpider):
    name = 'SwanseaBay'
    allowed_domains = ['sbuhb.nhs.wales']

    start_urls = ['https://sbuhb.nhs.wales/about-us/key-documents-meetings/']

    rules = (
        # as the entire website has inconsistent folder structure and use the same html tags and class names,
        # it is impossible to write generic rules. The specific, non nested urls covered in the first rule
        # Rule(LinkExtractor(allow=['annual-general-meeting']), callback='parse_item', follow=True),
        Rule(LinkExtractor(allow=['-papers', 'committee'], restrict_xpaths=(['//div[@class="mura-body"]//p'])), follow=True),
        Rule(LinkExtractor(deny=('standing-orders', 'annual-general-meeting', 'plans-policies-and-reports'),
                           restrict_xpaths=(['//div[@class="mura-body"]//li'])), callback='parse_html'),
    )

    def parse_html(self, response):
        # not every dl has a dt date tag
        dls = response.xpath('//div[@id="svIndex"]//dl').getall()
        for dl in dls:
            url = lxml.html.fromstring(dl).xpath('//a/@href')[0]
            date = lxml.html.fromstring(dl).xpath('//dt[@class="date releaseDate"]//text()')
            helper_item_type = lxml.html.fromstring(dl).xpath('//a/text()')[0]
            yield Request(
                url=response.urljoin(url),
                callback=self.parse_item,
                cb_kwargs=dict(helper_date=date,
                               helper_item_type=helper_item_type)
            )
        # https://sbuhb.nhs.wales/about-us/key-documents-folder/board-papers/may-2018-board-papers/
        # sometimes there are multiple pages; look for button next
        next_page = response.xpath('//li[contains(@class,"navNext")]//a/@href').get()
        if next_page:
            print('NEXT PAGE')
            yield Request(
                url=response.urljoin(next_page),
                callback=self.parse_html
            )

    def parse_item(self, response, helper_item_type, helper_date=[]):
        item = Item()
        item['name'] = self.name
        item['url'] = response.url
        item['response'] = response.body
        item['referer_url'] = response.request.headers.get('Referer').decode()
        item['helper_date'] = helper_date
        item['helper_item_type'] = helper_item_type
        item['content_type'] = response.headers['Content-Type'].decode()
        if response.headers.get('Last-Modified'):
            item['last_modified'] = response.headers.get('Last-Modified').decode()
        yield item
