# Installing pre-trained fastText word vectors
```bash
python -m spacy download en_core_web_sm
python -m spacy init-model en /tmp/la_vectors_wiki_lg --vectors-loc cc.la.300.vec.gz
```

# Depolying the crawler

To deploy the project, scrapyd-client has to be installed and Java 7+ has to be downloaded. Then run `pip install -r requirements.txt`

## Scrapyd-client
The documentation can be found: [Scrapyd-client](https://github.com/scrapy/scrapyd-client)

## Scrapyd
The documentation can be found: [Scrapyd](https://scrapyd.readthedocs.io/en/stable/overview.html)

## Dot-persistence
To save persistence file in S3 bucket, configure AWS credentials in settings file and enable the dot-persistence extension
The documentation can be found: [Dot-persistence] (https://github.com/scrapy-plugins/scrapy-dotpersistence)

1. Run `scrapyd` in a separate terminal

It will use the default settings configured in scrapyd.conf file.

2. To eggify and deploy the project run `scrapyd-deploy`

It will use the default settings configured in scrapy.cfg file. For full information visit the documentation page.

3. To schedule a run: `curl http://localhost:6800/schedule.json -d project=myproject -d spider=myspider`

When using widows curl, the curl command might not work. Either use virtual environment or configure a Postman request `http://localhost:6800/schedule.json?project=myproject&spider=myspider'

Other useful commands:
    * Check daemon status: `curl http://localhost:6800/daemonstatus.json`
    * List spiders : `curl http://localhost:6800/listspiders.json?project=myproject`
    * To cancel a run: `curl http://localhost:6800/cancel.json -d project=myproject -d job=6487ec79947edab326d6db28a2d86511e8247444`

## Scrapy
To run Spiders locally:
`scrapy crawl myspider`

To run a spider with dotpersistance on:
`scrapy crawl myspider -s JOBDIR=crawls/myspider`


Spiders available:
`scrapy crawl AneurinBevan`
`scrapy crawl BetsiCadwaladr`
`scrapy crawl CardiffVale`
`scrapy crawl Cavuhb`
`scrapy crawl CwmTafMorgannwg`
`scrapy crawl HywelDda`
`scrapy crawl Powys`
`scrapy crawl SwanseaBay`

# Searcg Engine

1. Make sure you have a folder named 'out' with the files you wish to create vocabulary for defined
2. Make sure you have created ES indexes for the vocabulary and documents
```json
PUT vocabulary
{
  "mappings": {
    "properties": {
      "vector": {
        "type": "dense_vector",
        "dims": 300
      },
      "word" : {
        "type" : "keyword"
      }
    }
  }
}
```

```json
PUT documents
{ "settings" : {
        "index" : {
            "number_of_shards" : 5, 
            "number_of_replicas" : 2 
        }
    },
  "mappings": {
    "properties": {
      "paragraphs": {
        "type": "nested" 
      }
    }
  }
}
```
3. Insert documents into ES by running `python insert_documents.py`
4. Create vocabulary by running `python create_vocabulary.py`. This might take a while
5. To query the index, modify the `main.py` with the queries and filters as you wish. This is the file to modify when building the front-end